Third Party Applications — Django Grappelli 2.7.2 documentation

# Third Party Applications

A list of 3rd-party applications compatible with Grappelli. Pleaes note that except of Django FileBrowser, these apps are not maintained by the team behind Grappelli. Compatibility with these apps is therefore not guaranteed and heavily relies on patches and pull-requests by the community.

## Django FileBrowser

No additional setup is needed when installing the Django FileBrowser with Grappelli.

## Django Reversion

Grappelli includes all necessary templates for Django Reversion.

Note

`grappelli` needs to be before `reversion` within `INSTALLED_APPS`.

## Django Smuggler

Grappelli includes all necessary templates for Django Smuggler.

Note

`grappelli` needs to be before `smuggler` within `INSTALLED_APPS`.

## Django Constance

Grappelli includes the necessary template for Django Constance.

Note

`grappelli` needs to be before `constance` within `INSTALLED_APPS`.